==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_va
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la sauvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estaa sauvagardaa dins @archive@. Poètz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => 'de vòstre sit.',

	// T
	'texte_admin_tech_01' => 'Aquela opcion vos permet de sauvagardar lo contengut de la basa dins un fichier que serà servat dins lo repertòri @dossier@.
Eissublietz pas tanpauc de recuperar l’integralitat dau repertòri <i>IMG/</i>, que conten los imatges e los documents utilizats dins los articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: aquela sauvagarda se poirà restaurar SOLAMENT dins un sit installat amb la mesma version d’SPIP. Donc sobretot chau pas "voidar la basa" en esperar de reïnstallar la sauvagarda après una actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’una sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquela opcion vos permet de restaurar una sauvagarda 
 de la basa que l’aviatz facha avans. Per aquò faire, chau aver botat lo fichier que conten la sauvagarda 
dins lo repertòri @dossier@.
  Pasmens, siatz prudent(a) amb aquela foncionalitat: <b>las modificacions e pèrdas eventualas son
  irreversiblas.</b>', # MODIF
	'texte_sauvegarde' => 'Sauvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardar la basa'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_va
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la sauvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estaa sauvagardaa dins @archive@. Poètz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => 'de vòstre sit.',

	// T
	'texte_admin_tech_01' => 'Aquela opcion vos permet de sauvagardar lo contengut de la basa dins un fichier que serà servat dins lo repertòri @dossier@.
Eissublietz pas tanpauc de recuperar l’integralitat dau repertòri <i>IMG/</i>, que conten los imatges e los documents utilizats dins los articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: aquela sauvagarda se poirà restaurar SOLAMENT dins un sit installat amb la mesma version d’SPIP. Donc sobretot chau pas "voidar la basa" en esperar de reïnstallar la sauvagarda après una actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’una sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquela opcion vos permet de restaurar una sauvagarda 
 de la basa que l’aviatz facha avans. Per aquò faire, chau aver botat lo fichier que conten la sauvagarda 
dins lo repertòri @dossier@.
  Pasmens, siatz prudent(a) amb aquela foncionalitat: <b>las modificacions e pèrdas eventualas son
  irreversiblas.</b>', # MODIF
	'texte_sauvegarde' => 'Sauvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardar la basa',
];
